@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2014 Jeffrey Stedfast
+ *  Copyright (C) 2000-2017 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -51,6 +51,7 @@ struct _GMimeStreamFilter {
 	struct _GMimeStreamFilterPrivate *priv;
 	
 	GMimeStream *source;
+	gboolean owner;
 };
 
 struct _GMimeStreamFilterClass {
@@ -66,6 +67,9 @@ GMimeStream *g_mime_stream_filter_new (GMimeStream *stream);
 int g_mime_stream_filter_add (GMimeStreamFilter *stream, GMimeFilter *filter);
 void g_mime_stream_filter_remove (GMimeStreamFilter *stream, int id);
 
+void g_mime_stream_filter_set_owner (GMimeStreamFilter *stream, gboolean owner);
+gboolean g_mime_stream_filter_get_owner (GMimeStreamFilter *stream);
+
 G_END_DECLS
 
 #endif /* __GMIME_STREAM_FILTER_H__ */
